Crate gossan_intel

Crate gossan_intel 

Intelligence scanner — online enrichment + offline bulk datasets.

Sources

  • GreyNoise
  • Censys host context v2
  • Shodan
  • AbuseIPDB
  • VirusTotal
  • URLScan
  • ASN (ipinfo.io)
  • Passive DNS

Caching

All enrichment is cached in a SQLite-backed TTL cache keyed by (source, target_type, target_value).

Modules

cache
Persistent TTL cache for intel enrichment.
db
SQLite-backed passive intelligence database.
enrichment
Typed enrichment contract for intelligence findings.
ingest
Bulk data ingestion from external sources into the intel database.
query
Target lookup against the passive intel database and online enrichment.
ratelimit
Per-service async rate limiting.
sources
Online intelligence source implementations — one source per file.

Structs

IntelScanner
Intel scanner configuration.