Modules
- cache
- Persistent TTL cache for intel enrichment.
- db
- SQLite-backed passive intelligence database.
- enrichment
- Typed enrichment contract for intelligence findings.
- ingest
- Bulk data ingestion from external sources into the intel database.
- query
- Target lookup against the passive intel database and online enrichment.
- ratelimit
- Per-service async rate limiting.
- sources
- Online intelligence source implementations — one source per file.
Structs
- Intel
Scanner - Intel scanner configuration.